@@ -38,7 +38,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Local
 #include <lib/document/documentfactory.h>
-#include <lib/thumbnailloadjob.h>
+#include <lib/thumbnailprovider/thumbnailprovider.h>
 
 namespace Gwenview
 {
@@ -207,7 +207,7 @@ void rename(const KUrl& oldUrl, QWidget* parent)
         job->ui()->showErrorMessage();
         return;
     }
-    ThumbnailLoadJob::moveThumbnail(oldUrl, newUrl);
+    ThumbnailProvider::moveThumbnail(oldUrl, newUrl);
 }
 
 } // namespace
