@@ -25,6 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QDateTime>
 #include <QDesktopWidget>
 #include <QLabel>
+#include <QPushButton>
 #include <QShortcut>
 #include <QSlider>
 #include <QSplitter>
@@ -49,6 +50,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KNotificationRestrictions>
 #include <KProtocolManager>
 #include <KLinkItemSelectionModel>
+#include <KRecentFilesAction>
 #include <KStatusBar>
 #include <KStandardDirs>
 #include <KStandardGuiItem>
@@ -75,9 +77,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "kipiinterface.h"
 #endif
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-#include <Nepomuk2/ResourceManager>
-#endif
 #include "semanticinfocontextmanageritem.h"
 #endif
 #include "preloader.h"
@@ -87,15 +86,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "startmainpage.h"
 #include "thumbnailviewhelper.h"
 #include "browsemainpage.h"
+#include <lib/hud/hudbuttonbox.h>
 #include <lib/archiveutils.h>
 #include <lib/contextmanager.h>
+#include <lib/disabledactionshortcutmonitor.h>
 #include <lib/document/documentfactory.h>
 #include <lib/documentonlyproxymodel.h>
 #include <lib/eventwatcher.h>
 #include <lib/gvdebug.h>
 #include <lib/gwenviewconfig.h>
-#include <lib/graphicshudlabel.h>
-#include <lib/graphicshudwidget.h>
 #include <lib/mimetypeutils.h>
 #include <lib/print/printhelper.h>
 #include <lib/slideshow.h>
@@ -188,6 +187,7 @@ struct MainWindow::Private
 #endif
 
     QActionGroup* mViewModeActionGroup;
+    KRecentFilesAction* mFileOpenRecentAction;
     KAction* mBrowseAction;
     KAction* mViewAction;
     KAction* mGoUpAction;
@@ -351,6 +351,12 @@ struct MainWindow::Private
                 q, SLOT(slotStartMainPageUrlSelected(KUrl)));
     }
 
+    void installDisabledActionShortcutMonitor(QAction* action, const char* slot)
+    {
+        DisabledActionShortcutMonitor* monitor = new DisabledActionShortcutMonitor(action, q);
+        connect(monitor, SIGNAL(activated()), q, slot);
+    }
+
     void setupActions()
     {
         KActionCollection* actionCollection = q->actionCollection();
@@ -360,6 +366,8 @@ struct MainWindow::Private
         file->addAction(KStandardAction::Save, q, SLOT(saveCurrent()));
         file->addAction(KStandardAction::SaveAs, q, SLOT(saveCurrentAs()));
         file->addAction(KStandardAction::Open, q, SLOT(openFile()));
+        mFileOpenRecentAction = KStandardAction::openRecent(q, SLOT(openUrl(KUrl)), q);
+        file->addAction("file_open_recent", mFileOpenRecentAction);
         file->addAction(KStandardAction::Print, q, SLOT(print()));
         file->addAction(KStandardAction::Quit, KApplication::kApplication(), SLOT(closeAllWindows()));
 
@@ -410,6 +418,7 @@ struct MainWindow::Private
         mGoToPreviousAction->setText(i18nc("@action Go to previous image", "Previous"));
         mGoToPreviousAction->setToolTip(i18nc("@info:tooltip", "Go to previous image"));
         mGoToPreviousAction->setShortcut(Qt::Key_Backspace);
+        installDisabledActionShortcutMonitor(mGoToPreviousAction, SLOT(showFirstDocumentReached()));
 
         mGoToNextAction = view->addAction("go_next", q, SLOT(goToNext()));
         mGoToNextAction->setPriority(QAction::LowPriority);
@@ -417,6 +426,7 @@ struct MainWindow::Private
         mGoToNextAction->setText(i18nc("@action Go to next image", "Next"));
         mGoToNextAction->setToolTip(i18nc("@info:tooltip", "Go to next image"));
         mGoToNextAction->setShortcut(Qt::Key_Space);
+        installDisabledActionShortcutMonitor(mGoToNextAction, SLOT(showLastDocumentReached()));
 
         mGoToFirstAction = view->addAction("go_first", q, SLOT(goToFirst()));
         mGoToFirstAction->setPriority(QAction::LowPriority);
@@ -511,16 +521,7 @@ struct MainWindow::Private
 
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
         SemanticInfoContextManagerItem* semanticInfoItem = 0;
-        // When using Nepomuk, create a SemanticInfoContextManagerItem instance
-        // only if Nepomuk is available
-        // When using Fake backend always create it
-#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-        if (Nepomuk2::ResourceManager::instance()->init() == 0) {
-#endif
-            semanticInfoItem = new SemanticInfoContextManagerItem(mContextManager, actionCollection, mViewMainPage);
-#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NEPOMUK
-        }
-#endif
+        semanticInfoItem = new SemanticInfoContextManagerItem(mContextManager, actionCollection, mViewMainPage);
 #endif
 
         ImageOpsContextManagerItem* imageOpsItem =
@@ -604,19 +605,6 @@ struct MainWindow::Private
         index = mDirModel->index(index.row() + offset, 0);
         if (index.isValid() && !indexIsDirOrArchive(index)) {
             goTo(index);
-        } else {
-            if (offset > 0) {
-                goToFirstDocument();
-            } else {
-                goToLastDocument();
-            }
-            if (mCurrentMainPageId == ViewMainPageId) {
-                showMessageBubble(
-                    offset > 0
-                    ? i18n("Last document reached, continuing on first document.")
-                    : i18n("First document reached, continuing on last document.")
-                );
-            }
         }
     }
 
@@ -642,19 +630,6 @@ struct MainWindow::Private
         goTo(index);
     }
 
-    void showMessageBubble(const QString &message)
-    {
-        GraphicsHudWidget* hud = new GraphicsHudWidget;
-        GraphicsHudLabel* label = new GraphicsHudLabel;
-        label->setText(message);
-        hud->init(label, GraphicsHudWidget::OptionNone);
-        hud->setContentsMargins(6, 6, 6, 6);
-        hud->setAutoDeleteOnFadeout(true);
-        QTimer::singleShot(2000, hud, SLOT(fadeOut()));
-
-        mViewMainPage->showMessageWidget(hud, Qt::AlignCenter);
-    }
-
     void setupFullScreenContent()
     {
         mFullScreenContent->init(q->actionCollection(), mViewMainPage, mSlideShow);
@@ -1119,6 +1094,10 @@ void MainWindow::slotPartCompleted()
 {
     d->updateActions();
     KUrl url = d->mViewMainPage->url();
+    //  remember the opened file
+    if (!url.isEmpty()) {
+        d->mFileOpenRecentAction->addUrl(url);
+    }
     if (!KProtocolManager::supportsListing(url)) {
         return;
     }
@@ -1253,10 +1232,9 @@ void MainWindow::updatePreviousNextActions()
         hasPrevious = false;
         hasNext = false;
     }
-    bool canBrowse = hasPrevious | hasNext;
 
-    d->mGoToPreviousAction->setEnabled(canBrowse);
-    d->mGoToNextAction->setEnabled(canBrowse);
+    d->mGoToPreviousAction->setEnabled(hasPrevious);
+    d->mGoToNextAction->setEnabled(hasNext);
     d->mGoToFirstAction->setEnabled(hasPrevious);
     d->mGoToLastAction->setEnabled(hasNext);
 }
@@ -1357,8 +1335,12 @@ void MainWindow::openFile()
         return;
     }
 
+    openUrl(dialog.selectedUrl());
+}
+
+void MainWindow::openUrl(const KUrl& url)
+{
     d->setActionsDisabledOnStartMainPageEnabled(true);
-    KUrl url = dialog.selectedUrl();
     d->mViewAction->trigger();
     d->mViewMainPage->openUrl(url);
     d->mContextManager->setUrlToSelect(url);
@@ -1480,6 +1462,7 @@ void MainWindow::loadConfig()
     d->mDirModel->setBlackListedExtensions(GwenviewConfig::blackListedExtensions());
     d->mDirModel->adjustKindFilter(MimeTypeUtils::KIND_VIDEO, GwenviewConfig::listVideos());
 
+    d->mFileOpenRecentAction->loadEntries(KConfigGroup(KGlobal::config(), "Recent Files"));
     d->mStartMainPage->loadConfig();
     d->mViewMainPage->loadConfig();
     d->mBrowseMainPage->loadConfig();
@@ -1487,6 +1470,7 @@ void MainWindow::loadConfig()
 
 void MainWindow::saveConfig()
 {
+    d->mFileOpenRecentAction->saveEntries(KConfigGroup(KGlobal::config(), "Recent Files"));
     d->mViewMainPage->saveConfig();
     d->mBrowseMainPage->saveConfig();
 }
@@ -1600,4 +1584,32 @@ void MainWindow::readProperties(const KConfigGroup& group)
     goToUrl(url);
 }
 
+void MainWindow::showFirstDocumentReached()
+{
+    if (d->mCurrentMainPageId != ViewMainPageId) {
+        return;
+    }
+    HudButtonBox* dlg = new HudButtonBox;
+    dlg->setText(i18n("You reached the first document, what do you want to do?"));
+    dlg->addButton(i18n("Stay There"));
+    dlg->addAction(d->mGoToLastAction, i18n("Go to the Last Document"));
+    dlg->addAction(d->mBrowseAction, i18n("Go Back to the Document List"));
+    dlg->addCountDown(15000);
+    d->mViewMainPage->showMessageWidget(dlg, Qt::AlignCenter);
+}
+
+void MainWindow::showLastDocumentReached()
+{
+    if (d->mCurrentMainPageId != ViewMainPageId) {
+        return;
+    }
+    HudButtonBox* dlg = new HudButtonBox;
+    dlg->setText(i18n("You reached the last document, what do you want to do?"));
+    dlg->addButton(i18n("Stay There"));
+    dlg->addAction(d->mGoToFirstAction, i18n("Go to the First Document"));
+    dlg->addAction(d->mBrowseAction, i18n("Go Back to the Document List"));
+    dlg->addCountDown(15000);
+    d->mViewMainPage->showMessageWidget(dlg, Qt::AlignCenter);
+}
+
 } // namespace
