@@ -112,6 +112,7 @@ private Q_SLOTS:
     void saveCurrent();
     void saveCurrentAs();
     void openFile();
+    void openUrl(const KUrl& url);
     void reload();
 
     void showDocumentInFullScreen(const KUrl&);
@@ -124,6 +125,9 @@ private Q_SLOTS:
 
     void toggleMenuBar();
 
+    void showFirstDocumentReached();
+    void showLastDocumentReached();
+
 private:
     struct Private;
     MainWindow::Private* const d;
