@@ -46,6 +46,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <importerconfigdialog.h>
 #include <serializedurlmap.h>
 #include <ui_thumbnailpage.h>
+#include <lib/thumbnailprovider/thumbnailprovider.h>
 
 namespace Gwenview
 {
@@ -82,11 +83,6 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
     ThumbnailPage* q;
     SerializedUrlMap mUrlMap;
 
-    ThumbnailPagePrivate()
-    {
-        mUrlMap.setConfigGroup(KConfigGroup(KGlobal::config(), URL_FOR_BASE_URL_GROUP));
-    }
-
     KIcon mSrcBaseIcon;
     QString mSrcBaseName;
     KUrl mSrcBaseUrl;
@@ -96,6 +92,8 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
     RecursiveDirModel* mRecursiveDirModel;
     QAbstractItemModel* mFinalModel;
 
+    ThumbnailProvider mThumbnailProvider;
+
     QPushButton* mImportSelectedButton;
     QPushButton* mImportAllButton;
     KUrl::List mUrlList;
@@ -183,6 +181,7 @@ struct ThumbnailPagePrivate : public Ui_ThumbnailPage
         mSlider->updateToolTip();
         mThumbnailView->setThumbnailAspectRatio(DEFAULT_THUMBNAIL_ASPECT_RATIO);
         mThumbnailView->setThumbnailWidth(thumbnailSize);
+        mThumbnailView->setThumbnailProvider(&mThumbnailProvider);
 
         QObject::connect(
             mThumbnailView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -233,6 +232,7 @@ ThumbnailPage::ThumbnailPage()
 : d(new ThumbnailPagePrivate)
 {
     d->q = this;
+    d->mUrlMap.setConfigGroup(KConfigGroup(KGlobal::config(), URL_FOR_BASE_URL_GROUP));
     d->setupUi(this);
     d->setupIcons();
     d->setupDirModel();
