@@ -72,8 +72,12 @@ void ImageScaler::setDocument(Document::Ptr document)
         disconnect(d->mDocument.data(), 0, this, 0);
     }
     d->mDocument = document;
+    // Used when scaler asked for a down-sampled image
     connect(d->mDocument.data(), SIGNAL(downSampledImageReady()),
             SLOT(doScale()));
+    // Used when scaler asked for a full image
+    connect(d->mDocument.data(), SIGNAL(loaded(KUrl)),
+            SLOT(doScale()));
 }
 
 void ImageScaler::setZoom(qreal zoom)
@@ -101,11 +105,6 @@ void ImageScaler::setDestinationRegion(const QRegion& region)
 
 void ImageScaler::doScale()
 {
-    if (d->mDocument->isBusy()) {
-        LOG("Document is busy, waiting");
-        QMetaObject::invokeMethod(this, "doScale", Qt::QueuedConnection);
-        return;
-    }
     if (d->mZoom < Document::maxDownSampledZoom()) {
         if (!d->mDocument->prepareDownSampledImageForZoom(d->mZoom)) {
             LOG("Asked for a down sampled image");
