@@ -49,6 +49,7 @@ extern "C" {
 #include "jpegerrormanager.h"
 #include "iodevicejpegsourcemanager.h"
 #include "exiv2imageloader.h"
+#include "gwenviewconfig.h"
 
 namespace Gwenview
 {
@@ -241,6 +242,10 @@ bool JpegContent::loadFromData(const QByteArray& data, Exiv2::Image* exiv2Image)
     d->mExifData = exiv2Image->exifData();
     d->mComment = QString::fromUtf8(exiv2Image->comment().c_str());
 
+    if (!GwenviewConfig::applyExifOrientation()) {
+        return true;
+    }
+
     // Adjust the size according to the orientation
     switch (orientation()) {
     case TRANSPOSE:
@@ -358,6 +363,8 @@ static QMatrix createScaleMatrix(int dx, int dy)
 struct OrientationInfo
 {
     OrientationInfo()
+    : orientation(NOT_AVAILABLE)
+    , jxform(JXFORM_NONE)
     {}
 
     OrientationInfo(Orientation o, QMatrix m, JXFORM_CODE j)
@@ -379,7 +386,7 @@ static const OrientationInfoList& orientationInfoList()
         QMatrix vflip = createScaleMatrix(1, -1);
 
         list
-                << OrientationInfo(NOT_AVAILABLE, QMatrix(), JXFORM_NONE)
+                << OrientationInfo()
                 << OrientationInfo(NORMAL, QMatrix(), JXFORM_NONE)
                 << OrientationInfo(HFLIP, hflip, JXFORM_FLIP_H)
                 << OrientationInfo(ROT_180, createRotMatrix(180), JXFORM_ROT_180)
