@@ -63,6 +63,26 @@ static void resolveAliasInList(QStringList* list)
     }
 }
 
+static void addRawMimeTypes(QStringList* list)
+{
+    // need to invent more intelligent way to whitelist raws
+    *list += "image/x-nikon-nef";
+    *list += "image/x-nikon-nrw";
+    *list += "image/x-canon-cr2";
+    *list += "image/x-canon-crw";
+    *list += "image/x-pentax-pef";
+    *list += "image/x-adobe-dng";
+    *list += "image/x-sony-arw";
+    *list += "image/x-minolta-mrw";
+    *list += "image/x-panasonic-raw";
+    *list += "image/x-panasonic-raw2";
+    *list += "image/x-samsung-srw";
+    *list += "image/x-olympus-orf";
+    *list += "image/x-fuji-raf";
+    *list += "image/x-kodak-dcr";
+    *list += "image/x-sigma-x3f";
+}
+
 const QStringList& rasterImageMimeTypes()
 {
     static QStringList list;
@@ -73,6 +93,7 @@ const QStringList& rasterImageMimeTypes()
         Q_FOREACH(const QString& mimeType, svgImageMimeTypes()) {
             list.removeOne(mimeType);
         }
+        addRawMimeTypes(&list);
     }
     return list;
 }
